==> moodle-1.4.5.tgz: moodle/lang/pt_br/editor.php <==
<?PHP // $Id: editor.php,v 1.4.2.5 2004/12/20 02:41:18 moodler Exp $ 
      // editor.php - created with Moodle 1.4.1 (2004083101)


$string['about'] = 'Informaes sobre este editor';
$string['absbottom'] = 'Embaixo';
$string['middle'] = 'No meio';
$string['address'] = 'Endereo';
$string['alignment'] = 'Alinhamento';
$string['alternatetext'] = 'Texto alternativo';
$string['anchorhelp'] = 'Isto cria apenas uma ncora.  necessrio criar o link manualmente.';
$string['anchorname'] = 'Nome da ncora';
$string['anchors'] = 'ncora';
$string['baseline'] = 'Linha-base';
$string['bold'] = 'Negrito';
$string['borderthickness'] = 'Espessura das bordas';
$string['bottom'] = 'Fundo';
$string['browse'] = 'Procurar';
$string['cancel'] = 'Cancelar';
$string['cellpadding'] = 'Distncia entre o texto e as bordas';
$string['cellspacing'] = 'Distncia entre clulas ';
$string['choosechar'] = 'Escolher caractere';
$string['chooseicon'] = 'Escolher imagem para inserir';
$string['close'] = 'Fechar';
$string['cols'] = 'Cols';
$string['copy'] = 'Copiar elemento selecionado';
$string['createanchor'] = 'Criar ncora';
$string['createfolder'] = 'Criar pasta';
$string['createlink'] = 'Inserir link web';
$string['cut'] = 'Cortar elemento selecionado';
$string['delete'] = 'Cancelar';
$string['filebrowser'] = 'Navegador de arquivos';
$string['forecolor'] = 'Cor das letras';
$string['fullscreen'] = 'Editor tela inteira';
$string['heading'] = 'Ttulo';
$string['height'] = 'Altura';
$string['hilitecolor'] = 'Cor do fundo';
$string['horizontal'] = 'Horizontal';
$string['horizontalrule'] = 'Linha Horizontal';
$string['htmlmode'] = 'Passar ao cdigo html';
$string['imageurl'] = 'URL da imagem';
$string['indent'] = 'Aumentar distncia da margem';
$string['insertchar'] = 'Inserir caractere especial';
$string['insertimage'] = 'Inserir imagem';
$string['insertlink'] = 'Inserir link';
$string['insertsmile'] = 'Inserir carinha';
$string['inserttable'] = 'Inserir tabela';
$string['italic'] = 'Itlico';
$string['justifycenter'] = 'Centralizar';
$string['justifyfull'] = 'Justificar';
$string['justifyleft'] = 'Alinhar  esquerda';
$string['justifyright'] = 'Alinhar  direita';
$string['layout'] = 'Layout';
$string['left'] = 'Esquerda';
$string['lefttoright'] = 'Da esquerda para a direita';
$string['linkproperties'] = 'Propriedades do link';
$string['linktarget'] = 'Target';
$string['linktargetblank'] = 'Nova janela';
$string['linktargetnone'] = 'Nenhum';
$string['linktargetother'] = 'Outro';
$string['linktargetself'] = 'Mesmo frame';
$string['linktargettop'] = 'Mesma janela';
$string['linktitle'] = 'Titulo';
$string['linkurl'] = 'URL';
$string['middle'] = 'Centro';
$string['minimize'] = 'Minimizar editor';
$string['move'] = 'Mover';
$string['normal'] = 'Normal';
$string['notimage'] = 'O arquivo selecionado no  uma imagem';
$string['notset'] = 'No definido';
$string['ok'] = 'OK';
$string['orderedlist'] = 'Listas Numeradas';
$string['outdent'] = 'Reduzir distncia da margem';
$string['paste'] = 'Colar';
$string['path'] = 'Caminho';
$string['percent'] = 'Porcentagem';
$string['pixels'] = 'Pixels';
$string['popupeditor'] = 'Aumentar o editor';
$string['preformatted'] = 'Formato predefinido';
$string['preview'] = 'Ver';
$string['properties'] = 'Propriedades';
$string['redo'] = 'Repetir a ltima ao';
$string['removelink'] = 'Remover link';
$string['rename'] = 'Mudar o nome';
$string['right'] = 'Direita';
$string['righttoleft'] = 'Da direita para a esquerda';
$string['rows'] = 'Linhas';
$string['selectcolor'] = 'Selecionar cor';
$string['selection'] = 'Seleo';
$string['showhelp'] = 'Ajuda para utilizar o editor';
$string['size'] = 'Tamanho';
$string['spacing'] = 'Distncia';
$string['strikethrough'] = 'Riscado';
$string['subscript'] = 'ndice';
$string['superscript'] = 'Expoente';
$string['textindicator'] = 'Estilo atual';
$string['textmode'] = 'Voc est usando a modalidae TEXTO. Use o boto [<>] para retornar  modalidade WYSIWYG.';
$string['texttop'] = 'Topo do texto';
$string['top'] = 'Topo';
$string['type'] = 'Tipo';
$string['underline'] = 'Sublinhar';
$string['undo'] = 'Cancelar a ltima ao';
$string['unorderedlist'] = 'Lista com marcadores';
$string['upload'] = 'Enviar';
$string['vertical'] = 'Vertical';
$string['width'] = 'Largura';
$string['wordclean'] = 'Limpar o html do word';
$string['zip'] = 'Zip';

?>

==> moodle-1.5.3.tgz: moodle/lang/pt_br/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.5 + (2005060201)


$string['about'] = 'Informaes sobre este editor';
$string['absbottom'] = 'Embaixo';
$string['address'] = 'Endereo';
$string['alertnoselectedtext'] = 'Selecione o texto antes!';
$string['alignment'] = 'Alinhamento';
$string['alternatetext'] = 'Texto alternativo';
$string['anchorhelp'] = 'Cria apenas uma ncora.  necessrio criar o link manualmente.';
$string['anchorname'] = 'Nome da ncora';
$string['anchors'] = 'ncoras';
$string['baseline'] = 'Linha-base';
$string['bold'] = 'Negrito';
$string['borderthickness'] = 'Espessura das bordas';
$string['bottom'] = 'Fundo';
$string['browse'] = 'Procurar';
$string['cancel'] = 'Cancelar';
$string['cellpadding'] = 'Distncia entre o texto e as bordas';
$string['cellspacing'] = 'Distncia entre clulas ';
$string['choosechar'] = 'Escolher caractere';
$string['chooseicon'] = 'Escolher imagem para inserir';
$string['close'] = 'Fechar';
$string['closeafterreplace'] = 'Fechar depois de substituir';
$string['cols'] = 'Cols';
$string['copy'] = 'Copiar elemento selecionado';
$string['createanchor'] = 'Criar ncora';
$string['createfolder'] = 'Criar pasta';
$string['createlink'] = 'Inserir link web';
$string['cut'] = 'Cortar elemento selecionado';
$string['cutpastemozilla'] = 'Infelizmente, no  possvel utilizar os atalhos de teclado usuais (nem mesmo o boto Colar), para colar texto neste editor. Isto se deve a uma funo de segurana de algumas verses dos navegadors Mozilla e Firefox. <br /><br />Voc pode experimentar 3 solues conhecidas:<br /><br />(1) Em vez de CTRL-v, use SHIFT-Insert<br />(2) Use o menu Editar->Colar de seu navegador<br />(3)Mude as preferncias de seu navegador editando o arquivo user.js.<br /><br />Clique no boto OK abaixo para mais ajuda, ou no boto Cancelar para voltar ao editor';
$string['delete'] = 'Cancelar';
$string['filebrowser'] = 'Navegador de arquivos';
$string['findwhat'] = 'Buscar';
$string['fontname'] = 'Nome do font';
$string['fontsize'] = 'Tamanho do font';
$string['forecolor'] = 'Cor das letras';
$string['formatblock'] = 'Formatar';
$string['fullscreen'] = 'Editor completo';
$string['heading'] = 'Ttulo';
$string['height'] = 'Altura';
$string['hilitecolor'] = 'Cor do fundo';
$string['horizontal'] = 'Horizontal';
$string['horizontalrule'] = 'Linha Horizontal';
$string['htmlmode'] = 'Passar ao cdigo html';
$string['imageurl'] = 'URL da imagem';
$string['indent'] = 'Aumentar distncia da margem';
$string['insertchar'] = 'Inserir caractere especial';
$string['insertimage'] = 'Inserir imagem';
$string['insertlink'] = 'Inserir link';
$string['insertsmile'] = 'Inserir carinha';
$string['inserttable'] = 'Inserir tabela';
$string['italic'] = 'Itlico';
$string['itemsreplaced'] = 'itens substitudos!';
$string['justifycenter'] = 'Centralizar';
$string['justifyfull'] = 'Justificar';
$string['justifyleft'] = 'Alinhar  esquerda';
$string['justifyright'] = 'Alinhar  direita';
$string['layout'] = 'Layout';
$string['left'] = 'Esquerda';
$string['lefttoright'] = 'Da esquerda para a direita';
$string['linkproperties'] = 'Propriedades do link';
$string['linktarget'] = 'Destinao';
$string['linktargetblank'] = 'Nova janela';
$string['linktargetnone'] = 'Nenhum';
$string['linktargetother'] = 'Outro';
$string['linktargetself'] = 'Mesmo frame';
$string['linktargettop'] = 'Mesma janela';
$string['linktitle'] = 'Titulo';
$string['linkurl'] = 'URL';
$string['matchcase'] = 'Considerar caixa alta ou baixa';
$string['middle'] = 'Centro';
$string['minimize'] = 'Minimizar editor';
$string['move'] = 'Mover';
$string['nolink'] = 'Evitar link automtico';
$string['normal'] = 'Normal';
$string['notimage'] = 'O arquivo selecionado no  uma imagem';
$string['notset'] = 'No definido';
$string['ok'] = 'OK';
$string['options'] = 'Opes';
$string['orderedlist'] = 'Listas Numeradas';
$string['outdent'] = 'Reduzir distncia da margem';
$string['paste'] = 'Colar';
$string['path'] = 'Caminho';
$string['percent'] = 'Porcentagem';
$string['pixels'] = 'Pixels';
$string['popupeditor'] = 'Aumentar o editor';
$string['preformatted'] = 'Formato predefinido';
$string['preview'] = 'Ver';
$string['properties'] = 'Propriedades';
$string['redo'] = 'Repetir a ltima ao';
$string['regularexpressions'] = 'Usar expresses regulares';
$string['removelink'] = 'Remover link';
$string['rename'] = 'Mudar o nome';
$string['replaceall'] = 'Substituir todos';
$string['replacewith'] = 'Substituir';
$string['right'] = 'Direita';
$string['righttoleft'] = 'Da direita para a esquerda';
$string['rows'] = 'Linhas';
$string['searchandreplace'] = 'Buscar e substituir';
$string['searchnotfound'] = 'Os termos da busca no foram encontrados';
$string['selectcolor'] = 'Selecionar cor';
$string['selection'] = 'Seleo';
$string['showhelp'] = 'Ajuda para utilizar o editor';
$string['size'] = 'Tamanho';
$string['spacing'] = 'Distncia';
$string['strikethrough'] = 'Riscado';
$string['subscript'] = 'ndice';
$string['superscript'] = 'Expoente';
$string['textindicator'] = 'Estilo atual';
$string['textmode'] = 'Voc est usando a modalidade TEXTO. Use o boto [<>] para retornar  modalidade WYSIWYG.';
$string['texttop'] = 'Topo do texto';
$string['top'] = 'Topo';
$string['type'] = 'Tipo';
$string['underline'] = 'Sublinhar';
$string['undo'] = 'Cancelar a ltima ao';
$string['unorderedlist'] = 'Lista com marcadores';
$string['upload'] = 'Enviar';
$string['vertical'] = 'Vertical';
$string['width'] = 'Largura';
$string['wordclean'] = 'Limpar o html do word';
$string['zip'] = 'Zip';

?>
